Font
====

The font class is used for abstracting the platforms implementation of fonts.

Supported Platforms
-------------------

.. include:: ../supported_platforms/Font.rst

Reference
---------

.. autoclass:: toga.interface.font.Font
   :members:
   :undoc-members:
   :inherited-members: